@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Rinci::Wrap;
 
-our $DATE = '2016-01-14'; # DATE
-our $VERSION = '0.12'; # VERSION
+our $DATE = '2016-06-02'; # DATE
+our $VERSION = '0.13'; # VERSION
 
 use 5.010001;
 use strict;
@@ -347,7 +347,7 @@ Dist::Zilla::Plugin::Rinci::Wrap - Insert wrapper-generated code
 
 =head1 VERSION
 
-This document describes version 0.12 of Dist::Zilla::Plugin::Rinci::Wrap (from Perl distribution Dist-Zilla-Plugin-Rinci-Wrap), released on 2016-01-14.
+This document describes version 0.13 of Dist::Zilla::Plugin::Rinci::Wrap (from Perl distribution Dist-Zilla-Plugin-Rinci-Wrap), released on 2016-06-02.
 
 =head1 SYNOPSIS
 
@@ -543,6 +543,15 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+If you are only concerned with argument validation, you can take a look at:
+L<Dist::Zilla::Plugin::Rinci::Validate>, L<Data::Sah::Manual::ParamsValidating>.
+
+If you are only concerned with function return validation, you can take a look
+at: L<Dist::Zilla::Plugin::Rinci::Validate>,
+L<Data::Sah::Manual::ResultValidating>.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
